==> qtjambi-quick3d-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiQuick3D/QQuick3DGeometry_Attribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick3D/qquick3dgeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick3D/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuick3DGeometry_Attribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuick3DGeometry::Attribute")
    QQuick3DGeometry::Attribute *_ptr = reinterpret_cast<QQuick3DGeometry::Attribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQuick3DGeometry_Attribute_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQuick3DGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::Attribute();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQuick3DGeometry::Attribute
void __qt_destruct_QQuick3DGeometry_Attribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuick3DGeometry::Attribute")
    reinterpret_cast<QQuick3DGeometry::Attribute*>(ptr)->~Attribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuick3DGeometry::Attribute::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::Attribute::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_Attribute_0, sizeof(QQuick3DGeometry::Attribute), typeid(QQuick3DGeometry::Attribute), false, &deleter_QQuick3DGeometry_Attribute, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQuick3DGeometry::Attribute::operator==(QQuick3DGeometry::Attribute,QQuick3DGeometry::Attribute)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_equals_1native_1cref_1QQuick3DGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID b1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuick3DGeometry::Attribute::operator==(QQuick3DGeometry::Attribute,QQuick3DGeometry::Attribute)", __qt_this)
        const QQuick3DGeometry::Attribute& __qt_b1 = QtJambiAPI::valueReferenceFromNativeId<QQuick3DGeometry::Attribute>(b1);
        __java_return_value = (*__qt_this) == __qt_b1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setComponentType_1native_1cref_1QQuick3DGeometry_1Attribute_1ComponentType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint componentType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QQuick3DGeometry::Attribute::ComponentType __qt_componentType0 = qtjambi_cast<QQuick3DGeometry::Attribute::ComponentType>(__jni_env, componentType0);
        __qt_this->componentType = QQuick3DGeometry::Attribute::ComponentType(__qt_componentType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_componentType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute::ComponentType&  __qt_value = __qt_this->componentType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<int>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setSemantic_1native_1cref_1QQuick3DGeometry_1Attribute_1Semantic__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint semantic0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QQuick3DGeometry::Attribute::Semantic __qt_semantic0 = qtjambi_cast<QQuick3DGeometry::Attribute::Semantic>(__jni_env, semantic0);
        __qt_this->semantic = QQuick3DGeometry::Attribute::Semantic(__qt_semantic0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_semantic_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute::Semantic&  __qt_value = __qt_this->semantic;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuick3DGeometry_Attribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuick3DGeometry::Attribute>("QQuick3DGeometry::Attribute", "io/qt/quick3d/QQuick3DGeometry$Attribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuick3DGeometry_Attribute, {
        ConstructorInfo(&__qt_construct_QQuick3DGeometry_Attribute_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuick3DGeometry_Attribute);
    registerMetaType<QQuick3DGeometry::Attribute>("QQuick3DGeometry::Attribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQuick3DGeometry::Attribute::ComponentType>("QQuick3DGeometry::Attribute::ComponentType", "io/qt/quick3d/QQuick3DGeometry$Attribute$ComponentType");
    registerEnumTypeInfo<QQuick3DGeometry::Attribute::Semantic>("QQuick3DGeometry::Attribute::Semantic", "io/qt/quick3d/QQuick3DGeometry$Attribute$Semantic");
// END: enums and flags
}

==> qtjambi-quick3d-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiQuick3D/QQuick3DGeometry_Attribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick3D/qquick3dgeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick3D/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQuick3DGeometry_Attribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQuick3DGeometry::Attribute")
    QQuick3DGeometry::Attribute *_ptr = reinterpret_cast<QQuick3DGeometry::Attribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Attribute()
void __qt_construct_QQuick3DGeometry_Attribute(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Attribute()")
    Q_UNUSED(__java_arguments)
    QQuick3DGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::Attribute();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::Attribute::Attribute()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::Attribute::Attribute()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_Attribute, sizeof(QQuick3DGeometry::Attribute), typeid(QQuick3DGeometry::Attribute), false, &deleter_QQuick3DGeometry_Attribute, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Attribute(QQuick3DGeometry::Attribute)
void __qt_construct_QQuick3DGeometry_Attribute_cref_QQuick3DGeometry_Attribute(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Attribute(QQuick3DGeometry::Attribute)")
    jobject other0 = __java_arguments[0].l;
    const QQuick3DGeometry::Attribute& __qt_other0 = qtjambi_cast<const QQuick3DGeometry::Attribute& >(__jni_env, other0);
    QQuick3DGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::Attribute(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::Attribute::Attribute(QQuick3DGeometry::Attribute)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_2Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::Attribute::Attribute(QQuick3DGeometry::Attribute)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_Attribute_cref_QQuick3DGeometry_Attribute, sizeof(QQuick3DGeometry::Attribute), typeid(QQuick3DGeometry::Attribute), false, &deleter_QQuick3DGeometry_Attribute, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Attribute{QQuick3DGeometry::Attribute::Semantic,int,QQuick3DGeometry::Attribute::ComponentType}
void __qt_construct_QQuick3DGeometry_Attribute_QQuick3DGeometry_Attribute_Semantic_int_QQuick3DGeometry_Attribute_ComponentType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Attribute{QQuick3DGeometry::Attribute::Semantic,int,QQuick3DGeometry::Attribute::ComponentType}")
    jobject semantic0 = __java_arguments[0].l;
    QQuick3DGeometry::Attribute::Semantic __qt_semantic0 = qtjambi_cast<QQuick3DGeometry::Attribute::Semantic>(__jni_env, semantic0);
    jint offset1 = __java_arguments[1].i;
    Q_UNUSED(offset1)
    jobject componentType2 = __java_arguments[2].l;
    QQuick3DGeometry::Attribute::ComponentType __qt_componentType2 = qtjambi_cast<QQuick3DGeometry::Attribute::ComponentType>(__jni_env, componentType2);
    QQuick3DGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QQuick3DGeometry::Attribute{QQuick3DGeometry::Attribute::Semantic(__qt_semantic0), static_cast<int>(offset1), QQuick3DGeometry::Attribute::ComponentType(__qt_componentType2)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QQuick3DGeometry::Attribute::Attribute{QQuick3DGeometry::Attribute::Semantic,int,QQuick3DGeometry::Attribute::ComponentType}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_initialize_1native__Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_2Lio_qt_quick3d_QQuick3DGeometry_00024Attribute_00024Semantic_2ILio_qt_quick3d_QQuick3DGeometry_00024Attribute_00024ComponentType_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject semantic0,
 jint offset1,
 jobject componentType2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQuick3DGeometry::Attribute::Attribute{QQuick3DGeometry::Attribute::Semantic,int,QQuick3DGeometry::Attribute::ComponentType}")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = semantic0;
        arguments[1].i = offset1;
        arguments[2].l = componentType2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQuick3DGeometry_Attribute_QQuick3DGeometry_Attribute_Semantic_int_QQuick3DGeometry_Attribute_ComponentType, sizeof(QQuick3DGeometry::Attribute), typeid(QQuick3DGeometry::Attribute), false, &deleter_QQuick3DGeometry_Attribute, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQuick3DGeometry::Attribute
void __qt_destruct_QQuick3DGeometry_Attribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQuick3DGeometry::Attribute")
    reinterpret_cast<QQuick3DGeometry::Attribute*>(ptr)->~Attribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQuick3DGeometry::Attribute::operator==(QQuick3DGeometry::Attribute,QQuick3DGeometry::Attribute)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_equals_1native_1cref_1QQuick3DGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID b1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQuick3DGeometry::Attribute::operator==(QQuick3DGeometry::Attribute,QQuick3DGeometry::Attribute)", __qt_this)
        const QQuick3DGeometry::Attribute& __qt_b1 = QtJambiAPI::valueReferenceFromNativeId<QQuick3DGeometry::Attribute>(b1);
        __java_return_value = (*__qt_this) == __qt_b1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setComponentType_1native_1cref_1QQuick3DGeometry_1Attribute_1ComponentType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint componentType0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QQuick3DGeometry::Attribute::ComponentType __qt_componentType0 = qtjambi_cast<QQuick3DGeometry::Attribute::ComponentType>(__jni_env, componentType0);
        __qt_this->componentType = QQuick3DGeometry::Attribute::ComponentType(__qt_componentType0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_componentType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute::ComponentType&  __qt_value = __qt_this->componentType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<int>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_setSemantic_1native_1cref_1QQuick3DGeometry_1Attribute_1Semantic__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint semantic0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QQuick3DGeometry::Attribute::Semantic __qt_semantic0 = qtjambi_cast<QQuick3DGeometry::Attribute::Semantic>(__jni_env, semantic0);
        __qt_this->semantic = QQuick3DGeometry::Attribute::Semantic(__qt_semantic0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_semantic_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QQuick3DGeometry::Attribute::Semantic&  __qt_value = __qt_this->semantic;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick3d_QQuick3DGeometry_00024Attribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QQuick3DGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QQuick3DGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QQuick3DGeometry_Attribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QQuick3DGeometry::Attribute>("QQuick3DGeometry::Attribute", "io/qt/quick3d/QQuick3DGeometry$Attribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQuick3DGeometry_Attribute, {
        ConstructorInfo(&__qt_construct_QQuick3DGeometry_Attribute, nullptr)
       ,ConstructorInfo(&__qt_construct_QQuick3DGeometry_Attribute_cref_QQuick3DGeometry_Attribute, "Lio/qt/quick3d/QQuick3DGeometry$Attribute;")
       ,ConstructorInfo(&__qt_construct_QQuick3DGeometry_Attribute_QQuick3DGeometry_Attribute_Semantic_int_QQuick3DGeometry_Attribute_ComponentType, "Lio/qt/quick3d/QQuick3DGeometry$Attribute$Semantic;ILio/qt/quick3d/QQuick3DGeometry$Attribute$ComponentType;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQuick3DGeometry_Attribute);
    registerMetaType<QQuick3DGeometry::Attribute>("QQuick3DGeometry::Attribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQuick3DGeometry::Attribute::ComponentType>("QQuick3DGeometry::Attribute::ComponentType", "io/qt/quick3d/QQuick3DGeometry$Attribute$ComponentType");
    registerEnumTypeInfo<QQuick3DGeometry::Attribute::Semantic>("QQuick3DGeometry::Attribute::Semantic", "io/qt/quick3d/QQuick3DGeometry$Attribute$Semantic");
// END: enums and flags
}
